aboutsummaryrefslogtreecommitdiff
path: root/include/app.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/app.h')
-rw-r--r--include/app.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/include/app.h b/include/app.h
index cb09b04..a420f00 100644
--- a/include/app.h
+++ b/include/app.h
@@ -46,8 +46,8 @@ typedef struct app {
size_t prompt_input_len;
/*
* File/path prompt completion state for find-file and write-file.
* prompt_completion_query stores the original typed path/query while
* prompt_input is temporarily replaced with the selected candidate.
*/
int prompt_completion_active;
@@ -75,6 +75,10 @@ typedef struct app {
int current_mods;
+ buffer_t *mouse_capture_buffer;
+ int mouse_capture_button;
+ int mouse_capture_active;
+
/*
* GLFW sends key events and text events separately. When a printable
* key is consumed as part of a command sequence, suppress the matching
@@ -46,8 +46,8 @@ typedef struct app {
size_t prompt_input_len;
/*
- * File/path prompt completion state for find-file and write-file.
- * prompt_completion_query stores the original typed path/query while
+ * Prompt completion state for path prompts and buffer prompts.
+ * prompt_completion_query stores the original typed query while
* prompt_input is temporarily replaced with the selected candidate.
*/